Function to test for the joint genetic and gene-environment
interaction effects for a set of variant using a LRT model
Usage
GxEscreen(dat, geno, nsim = 1e+05, K = 7)
Arguments
dat
a data frame with covariate information. Col 1 should be phenotype,
col 2 should be environmental factor, col 3 and later should be additional covariates
geno
a genotype matrix with 0-1-2 coding
nsim
the number of replicates in obtaining the p-value (standard 1e5)
K
the number of knots used to control the flexibility in modeling GxE interaction
Value
a vector containing the p-value from the LRT associated with each SNP